/**
 * @file paint.c
 * @brief Implements the painting functionality for the TreeMap visualization.
 *
 * This file contains functions to paint the tree by printing each node's bounding box dimensions
 * and associated labels in a readable format.
 */

/**
 * @brief Paints the TreeNode structure by printing bounding box details.
 *
 * This function recursively traverses the tree and prints out the dimensions of each leaf node's
 * bounding box. Internal nodes are also traversed, but only leaf nodes are painted (printed).
 *
 * @param node Pointer to the TreeNode to be painted.
 */
void paint(TreeNode *node) {
    if (!node) return;

    // Si c'est une feuille (feuille = node->data existe)
    if (node->data) {
        // Multiplier toutes les coordonnées et tailles par 100
        double scaled_x = node->box.x * 100;
        double scaled_y = node->box.y * 100;
        double scaled_w = node->box.w * 100;
        double scaled_h = node->box.h * 100;
        
        // Afficher les valeurs mises à l'échelle
        printf("%.2f:%.2f:%.2f:%.2f:%s\n",
               scaled_x,
               scaled_y,
               scaled_w,
               scaled_h,
               node->data->label ? node->data->label : "unknown");
    } else {
        // Sinon, on parcourt les enfants
        for (int i = 0; i < node->num_children; i++) {
            paint(node->children[i]);  // Appel récursif sur les enfants
        }
    }
}
