/**
 * @file place.h
 * @brief Header file for the placement functions.
 * 
 * Defines the Box and TreeNode structures used to organize data in a visual representation.
 */

typedef struct Box {
    double x, y;   /**< Coordinates of the upper-left corner of the box. */
    double w, h;   /**< Width and height of the box. */
} Box;

/**
 * @brief TreeNode structure that forms the basis of the Treemap.
 * 
 * This structure holds information for each node, including its children, its value sum, and its position.
 */

typedef struct TreeNode {
    double sum;                /**< Sum of the values */
    struct TreeNode **children;  /**< Array of pointers to child nodes */
    int num_children;          /**< Number of children */
    Data *data;                /**< Pointer to data (NULL for internal nodes) */
    Box box;                   /**< The assigned box for node */
} TreeNode;


