/**
 * @file split-binary.c
 * @brief Implements the binary split algorithm.
 */

/**
 * @brief Recursively splits the data array into two groups.
 * 
 * This function takes a portion of the array and keeps dividing it until it can't be split further.
 * 
 * @param array Pointer to the data array.
 * @param start The starting index for the split.
 * @param end The ending index for the split.
 */


// Recursive function to perform binary splitting (right group larger)
void binary_split(Data *array, int start, int end) {
    // Base case: if the sub-array contains only one element
    if (start == end) {
        return;
    }

    // Calculate the middle index, giving the second sub-section (right group) the larger half if odd
    int size = end - start + 1;
    int mid = start + (size + 1) / 2;  // Larger right side

    // Recursively split the left and right sub-groups
    binary_split(array, start, mid - 1);  // First group (left)
    binary_split(array, mid, end);       // Second group (right)
}
