#!/bin/bash

#
# This turns a "vector" output into a LaTeX file. Use it as:
#
#     ./treemap ... | ./vector2tex.sh > whatever.tex
#     pdflatex whatever.tex
#
# or on a prepared file, as:
#
#     ./treemap ... > whatever.vector
#     ./vector2tex.sh < whatever.vector > whatever.tex
#     pdflatex whatever.tex
#
# If your "vector" file is not correct, expect bizarre errors.
# If labels are present, they are typeset as TeX.
#

cat <<"EOF"
\documentclass[tikz]{standalone}
\usetikzlibrary{calc}
\newcounter{COLOR}
\newcommand{\PLAIN}[5]{%
  \pgfmathparse{20+20*(Mod(\value{COLOR},5))}
  \colorlet{backcolor}{purple!\pgfmathresult}
  \stepcounter{COLOR}
  \path[draw=black,fill=backcolor]
  (#1,#2) coordinate(ul) rectangle ++(#3,#4) coordinate (lr);
  \path ($(ul)!0.5!(lr)$) node[overlay] {#5};
}
\begin{document}
\begin{tikzpicture}[x=0.1cm,y=-0.1cm]

EOF

sed -e 's/^/\\PLAIN{/' -e 's/:/}{/g' -e 's/$/}/'

cat <<"EOF"

\end{tikzpicture}%
\end{document}
EOF

